# Welcome to pydagroas
![alt text](images/pydagoras.png "pydagoras")

## Introduction
pydagoras is a Python package to create Directed Acyclic Graphs ([DAG](https://en.wikipedia.org/wiki/Directed_acyclic_graph)s) </br>
</br>
The aim of this site is to;

* Document the pypi package [pydagoras](https://pypi.org/project/pydagoras) that underpins the demo site.
* Show an example script that uses `pydagoras`.
* Document the [demo site](https://pydagoras.com)  where the example app can be seen and used.
* Explian how the how the demo app has been built.:

## [Package](package.md)
pydagoras can be installed from PyPi, which can be reached using the Python link the bottom right corner of this page.</br>
The package section details;

* Other ways to get pydagoras
* What is included in the package

## [Example script](example_script.md)
This section documents the script `eg_use_pydagoras.py` that is included in the test folder of the package. It provides an example of;

* How to constuct a DAG using pydagoras by creating and linking nodes
* Updating inputs
* Accessing the output

## [Demo](demo.md)
In this section there is a link to the demo site, it details how to use the demo site and how to make and see changes to the three example DAGs.
It also shows a video showing the three example pydagoras DAGs being updated.

## [Example app](example_app.md)
This section explains how the example app has been built, with a front end, that connects to a backend that uses pydagoras. 

## [Code reference](reference.md)
This section allows you to look into the code behind the pydagoras package.

------
